@@ -1,3 +1,5 @@
+import os
+import sys
 import argparse as ap
 from .action import GetTaskListAction
 from .exc import TaskAlreadyExists, TaskNotExists
@@ -36,6 +38,8 @@ def parse_task():
 
 
 def do_task():
+    # append current directory into path to get tasks directory
+    sys.path.append(os.getcwd())
     try:
         import tasks as t
     except ModuleNotFoundError:
